@@ -506,9 +506,10 @@ def cbcBayesPostProc(
             extract_hdf5_metadata(h5grp,parent=html_hdf)
 
     #Create a section for model selection results (if they exist)
-    if bayesfactornoise is not None:
+    if bayesfactorcoherent is not None or bayesfactornoise is not None:
         html_model=html.add_section('Model selection',legend=legend)
-        html_model.p('log Bayes factor ( coherent vs gaussian noise) = %s, Bayes factor=%f'%(BSN,exp(float(BSN))))
+        if bayesfactornoise is not None:
+            html_model.p('log Bayes factor ( coherent vs gaussian noise) = %s, Bayes factor=%f'%(BSN,exp(float(BSN))))
         if bayesfactorcoherent is not None:
             html_model.p('log Bayes factor ( coherent vs incoherent OR noise ) = %s, Bayes factor=%f'%(BCI,exp(float(BCI))))
 
@@ -661,7 +662,11 @@ def cbcBayesPostProc(
       if not os.path.isdir(psddir):
         os.makedirs(psddir)
       try:
-        bppu.plot_psd(psd_files,outpath=psddir)
+        if 'flow' in pos.names:
+          f_low = pos['flow'].samples.min()
+        else:
+          f_low = 30.
+        bppu.plot_psd(psd_files,outpath=psddir, f_min=f_low)
         wfsection.write('<a href="PSDs/PSD.png" target="_blank"><img src="PSDs/PSD.png"/></a>')
       except  Exception,e:
         print "Could not create PSD plot. The error was: %s\n"%str(e)
