@@ -25,10 +25,7 @@ class ExtractCoincInspiralTableLIGOLWContentHandler(ligolw.PartialLIGOLWContentH
   """
   def __init__(self,document):
     def filterfunc(name,attrs):
-      if name==ligolw.Table.tagName and attrs.has_key('Name'):
-        return 0==table.CompareTableNames(attrs.get('Name'), lsctables.CoincInspiralTable.tableName)
-      else:
-        return False
+      return name==ligolw.Table.tagName and attrs.has_key('Name') and table.Table.TableName(attrs.get('Name'))==lsctables.CoincInspiralTable.tableName
     ligolw.PartialLIGOLWContentHandler.__init__(self,document,filterfunc)
 
 
