@@ -56,8 +56,7 @@ def ReadMultiInspiralFromFiles(fileList):
         gz=(thisFile or "stdin").endswith(".gz"), contenthandler = lsctables.use_in(ligolw.LIGOLWContentHandler))
     # extract the multi inspiral table
     try:
-      multiInspiralTable = table.get_table(doc,
-          lsctables.MultiInspiralTable.tableName)
+      multiInspiralTable = lsctables.MultiInspiralTable.get_table(doc)
       if multis: multis.extend(multiInspiralTable)
       else: multis = multiInspiralTable
     except: multiInspiralTable = None
@@ -80,8 +79,7 @@ def ReadMultiInspiralTimeSlidesFromFiles(fileList,generate_output_tables=False):
     doc = utils.load_filename(thisFile,
         gz=(thisFile or "stdin").endswith(".gz"), contenthandler = lsctables.use_in(ligolw.LIGOLWContentHandler))
     # Extract the time slide table
-    timeSlideTable = table.get_table(doc,
-          lsctables.TimeSlideTable.tableName)
+    timeSlideTable = lsctables.TimeSlideTable.get_table(doc)
     slideMapping = {}
     currSlides = {}
     # NOTE: I think some of this is duplicated in the glue definition of the
@@ -106,14 +104,12 @@ def ReadMultiInspiralTimeSlidesFromFiles(fileList,generate_output_tables=False):
 
     # Get the mapping table
     segmentMap = {}
-    timeSlideMapTable = table.get_table(doc,
-        lsctables.TimeSlideSegmentMapTable.tableName)
+    timeSlideMapTable = lsctables.TimeSlideSegmentMapTable.get_table(doc)
     for entry in timeSlideMapTable:
       segmentMap[int(entry.segment_def_id)] = int(entry.time_slide_id)
 
     # Extract the segment table
-    segmentTable = table.get_table(doc,
-        lsctables.SegmentTable.tableName)
+    segmentTable = lsctables.SegmentTable.get_table(doc)
     for entry in segmentTable:
       currSlidId = segmentMap[int(entry.segment_def_id)]
       currSeg = entry.get()
@@ -124,8 +120,7 @@ def ReadMultiInspiralTimeSlidesFromFiles(fileList,generate_output_tables=False):
     
     # extract the multi inspiral table
     try:
-      multiInspiralTable = table.get_table(doc,
-          lsctables.MultiInspiralTable.tableName)
+      multiInspiralTable = lsctables.MultiInspiralTable.get_table(doc)
       # Remap the time slide IDs
       for multi in multiInspiralTable:
         newID = slideMapping[int(multi.time_slide_id)]
