@@ -49,10 +49,7 @@ class ExtractSnglInspiralTableLIGOLWContentHandler(ligolw.PartialLIGOLWContentHa
   """
   def __init__(self,document):
     def filterfunc(name,attrs):
-      if name==ligolw.Table.tagName and attrs.has_key('Name'):
-        return 0==table.CompareTableNames(attrs.get('Name'), lsctables.SnglInspiralTable.tableName)
-      else:
-        return False
+      return name==ligolw.Table.tagName and attrs.has_key('Name') and table.Table.TableName(attrs.get('Name'))==lsctables.SnglInspiralTable.tableName
     ligolw.PartialLIGOLWContentHandler.__init__(self,document,filterfunc)
 
 
