@@ -38,8 +38,4 @@ __date__ = git_version.date
 
 
 from xlal.datatypes.ligotimegps import *
-from xlal.datatypes.simburst import *
-from xlal.datatypes.siminspiraltable import *
-from xlal.datatypes.snglburst import *
-from xlal.datatypes.snglinspiraltable import *
 from xlal.datatypes.snglringdowntable import *
