@@ -314,8 +314,8 @@ def exttrig_dataquery(grb_name, grb_time, grb_ra, grb_dec, offset, config_file,
 
 	# load the content of the veto-file
         xmldoc = utils.load_filename(xmlsegfile, gz = False, contenthandler = lsctables.use_in(ligolw.LIGOLWContentHandler))
-	segs = table.get_table(xmldoc, lsctables.SegmentTable.tableName)
-	segdefs = table.get_table(xmldoc, lsctables.SegmentDefTable.tableName)
+	segs = lsctables.SegmentTable.get_table(xmldoc)
+	segdefs = lsctables.SegmentDefTable.get_table(xmldoc)
 
 	# create a mapping between the segments and their definitions
 	defdict = {}
@@ -578,8 +578,8 @@ def exttrig_dataquery(grb_name, grb_time, grb_ra, grb_dec, offset, config_file,
       for ifo in ifolist:
 	vetofile = "%s-VETOTIME_CAT%s_grb%s.xml" % (ifo, cat, grb_name)
         xmldoc = utils.load_filename(vetofile, gz = False, contenthandler = lsctables.use_in(ligolw.LIGOLWContentHandler))
-	segs = table.get_table(xmldoc, lsctables.SegmentTable.tableName)
-	segdefs = table.get_table(xmldoc, lsctables.SegmentDefTable.tableName)
+	segs = lsctables.SegmentTable.get_table(xmldoc)
+	segdefs = lsctables.SegmentDefTable.get_table(xmldoc)
 	vetodict[ifo] = segments.segmentlist(segments.segment(s.start_time, s.end_time) for s in segs)
 
       if vetodict:
@@ -595,7 +595,7 @@ if __name__ == "__main__":
   # get time, RA, DEC and name of GRB; get offset to search from GRB time
   if opts.grb_file:
     xmldoc    = utils.load_filename(opts.grb_file, gz=opts.grb_file.endswith('.gz'), contenthandler = lsctables.use_in(ligolw.LIGOLWContentHandler))
-    ext_table = table.get_table(xmldoc,lsctables.ExtTriggersTable.tableName)
+    ext_table = lsctables.ExtTriggersTable.get_table(xmldoc)
     grb_time  = ext_table[0].start_time
     grb_name  = os.path.basename(opts.grb_file)[3:-4]
     grb_ra    = ext_table[0].event_ra
