@@ -1,7 +1,7 @@
-id = "ab01f4b1ec69973f827154b1be58e77c546d96b8"
-date = "2016-10-18 09:26:01 +0000"
+id = "b89067e5194d24a22f33a90a016eb4527ac65293"
+date = "2017-02-08 05:50:23 +0000"
 branch = "master"
-tag = "None"
+tag = "pylal-v0.13.1-v1"
 if tag == "None":
     tag = None
 author = "Kipp Cannon <kipp.cannon@ligo.org>"
@@ -10,11 +10,11 @@ committer = "Kipp Cannon <kipp.cannon@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
 verbose_msg = """Branch: master
-Tag: None
-Id: ab01f4b1ec69973f827154b1be58e77c546d96b8
+Tag: pylal-v0.13.1-v1
+Id: b89067e5194d24a22f33a90a016eb4527ac65293
 
 Builder: Kipp Cannon <kipp.cannon@ligo.org>
-Build date: 2016-10-18 09:26:39 +0000
+Build date: 2017-02-08 05:51:31 +0000
 Repository status: CLEAN: All modifications committed"""
 
 import warnings
@@ -33,9 +33,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError, onmismatch + " is an unrecognized value of onmismatch"
-    if foreign_id == "ab01f4b1ec69973f827154b1be58e77c546d96b8":
+    if foreign_id == "b89067e5194d24a22f33a90a016eb4527ac65293":
         return
-    msg = "Program id (ab01f4b1ec69973f827154b1be58e77c546d96b8) does not match given id (%s)." % foreign_id
+    msg = "Program id (b89067e5194d24a22f33a90a016eb4527ac65293) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError, msg
 
