@@ -52,7 +52,6 @@ import warnings
 import lal
 
 
-from glue import iterutils
 from glue import offsetvector
 from glue import segmentsUtils
 from glue.ligolw import ligolw
@@ -442,7 +441,7 @@ class TimeSlideGraphNode(object):
 		# used by any other components, they definitely won't be
 		# used to construct our n-instrument coincs, and so they go
 		# into our unused pile
-		for componenta, componentb in iterutils.choices(self.components, 2):
+		for componenta, componentb in itertools.combinations(self.components, 2):
 			self.unused_coincs |= componenta.unused_coincs & componentb.unused_coincs
 
 		if verbose:
@@ -507,7 +506,7 @@ class TimeSlideGraphNode(object):
 					# remove them from the unused list
 					# because we just used them, then
 					# record the coinc and move on
-					self.unused_coincs -= set(iterutils.choices(new_coinc, len(new_coinc) - 1))
+					self.unused_coincs -= set(itertools.combinations(new_coinc, len(new_coinc) - 1))
 					self.coincs.append(new_coinc)
 		if verbose:
 			print >>sys.stderr, "\t100.0%"
@@ -814,8 +813,6 @@ class CoincSynthesizer(object):
 		self.min_instruments = min_instruments
 		self.abundance_rel_accuracy = abundance_rel_accuracy
 
-		self.verbose = False	# turn on for diagnostics
-
 
 	def reset(self):
 		"""
@@ -842,7 +839,7 @@ class CoincSynthesizer(object):
 		except AttributeError:
 			pass
 		try:
-			del self._rates
+			del self._coincidence_rate_factors
 		except AttributeError:
 			pass
 
@@ -854,7 +851,7 @@ class CoincSynthesizer(object):
 		frozensets).
 		"""
 		all_instruments = tuple(self.eventlists)
-		return tuple(frozenset(instruments) for n in range(self.min_instruments, len(all_instruments) + 1) for instruments in iterutils.choices(all_instruments, n))
+		return tuple(frozenset(instruments) for n in range(self.min_instruments, len(all_instruments) + 1) for instruments in itertools.combinations(all_instruments, n))
 
 
 	@property
@@ -910,11 +907,6 @@ class CoincSynthesizer(object):
 	@mu.setter
 	def mu(self, val):
 		self._mu = val
-		# force re-computation of coincidence rates
-		try:
-			del self._rates
-		except AttributeError:
-			pass
 
 
 	@property
@@ -930,7 +922,7 @@ class CoincSynthesizer(object):
 		try:
 			return self._tau
 		except AttributeError:
-			self._tau = dict((frozenset(ab), self.delta_t + light_travel_time(*ab)) for ab in iterutils.choices(tuple(self.eventlists), 2))
+			self._tau = dict((frozenset(ab), self.delta_t + light_travel_time(*ab)) for ab in itertools.combinations(tuple(self.eventlists), 2))
 			return self._tau
 
 
@@ -939,11 +931,121 @@ class CoincSynthesizer(object):
 		self._tau = val
 		# force re-computation of coincidence rates
 		try:
-			del self._rates
+			del self._coincidence_rate_factors
 		except AttributeError:
 			pass
 
 
+	@property
+	def coincidence_rate_factors(self):
+		"""
+		For instruments {1, ..., N}, with rates \mu_{1}, ...,
+		\mu_{N}, the rate of coincidences is
+
+		\propto \prod_{i} \mu_{i}.
+
+		The proportionality constant depends only on the
+		coincidence windows.  This function computes and returns a
+		dictionary of the proportionality constants keyed by
+		instrument set.
+
+		The return value is a reference to an internally-cached
+		dictionary.  Modifications will be retained until the
+		cached data is regenerated (after .reset() is invoked or
+		the .tau attribute is assigned to).
+		"""
+		try:
+			return self._coincidence_rate_factors
+		except AttributeError:
+			pass
+
+		# initialize the proportionality constants
+		self._coincidence_rate_factors = dict.fromkeys(self.all_instrument_combos, 1.0)
+
+		for instruments in self.all_instrument_combos:
+		# choose the instrument whose TOA forms the "epoch" of the
+		# coinc.  to improve the convergence rate this should be
+		# the instrument with the smallest Cartesian product of
+		# coincidence windows with other instruments (so that
+		# coincidence with this instrument provides the tightest
+		# prior constraint on the time differences between the
+		# other instruments).
+			key = instruments
+			anchor = min(instruments, key = lambda a: sum(math.log(self.tau[frozenset((a, b))]) for b in instruments - set([a])))
+			instruments = tuple(instruments - set([anchor]))
+		# the computation of a coincidence rate starts by computing
+		# \mu_{1} * \mu_{2} ... \mu_{N} * 2 * \tau_{12} * 2 *
+		# \tau_{13} ... 2 * \tau_{1N}.  this is the rate at which
+		# events from instrument 1 are coincident with events from
+		# all of instruments 2...N.  later, we will multiply this
+		# by the probability that events from instruments 2...N
+		# known to be coincident with an event from instrument 1
+		# are themselves mutually coincident.  the factor of 2 is
+		# because to be coincident the time difference can be
+		# anywhere in [-tau, +tau], so the size of the coincidence
+		# window is 2 tau.  here we compute the part of the
+		# expression with the \mu factors removed.
+			for instrument in instruments:
+				self._coincidence_rate_factors[key] *= 2. * self.tau[frozenset((anchor, instrument))]
+
+		# if there are more than two instruments, correct for the
+		# probability of full N-way coincidence by computing the
+		# volume of the allowed parameter space by stone throwing.
+		# FIXME:  it might be practical to solve this with some
+		# sort of computational geometry library and convex hull
+		# volume calculator.
+			if len(instruments) > 1:
+		# for each instrument 2...N, the interval within which an
+		# event is coincident with instrument 1
+				windows = tuple((-self.tau[frozenset((anchor, instrument))], +self.tau[frozenset((anchor, instrument))]) for instrument in instruments)
+		# pre-assemble a sequence of instrument index pairs and the
+		# maximum allowed \Delta t between them to avoid doing the
+		# work associated with assembling the sequence inside a
+		# loop
+				ijseq = tuple((i, j, self.tau[frozenset((instruments[i], instruments[j]))]) for (i, j) in itertools.combinations(range(len(instruments)), 2))
+		# compute the numerator and denominator of the fraction of
+		# events coincident with the anchor instrument that are
+		# also mutually coincident.  this is done by picking a
+		# vector of allowed \Delta ts and testing them against the
+		# coincidence windows.  the loop's exit criterion is
+		# arrived at as follows.  after d trials, the number of
+		# successful outcomes is a binomially-distributed RV with
+		# variance = d p (1 - p) <= d/4 where p is the probability
+		# of a successful outcome.  we quit when the ratio of the
+		# bound on the standard deviation of the number of
+		# successful outcomes (d/4) to the actual number of
+		# successful outcomes (n) falls below rel accuracy:
+		# \sqrt{d/4} / n < rel accuracy, or
+		#
+		# \sqrt{d} < 2 * rel accuracy * n
+		#
+		# note that if the true probability is 0, so that n=0
+		# identically, then the loop will never terminate; from the
+		# nature of the problem we know 0<p<1 so the loop will,
+		# eventually, terminate.  note that if instead of using the
+		# upper bound on the variance, we replace p with the
+		# estimate of p at the current iteration (=n/d) and use
+		# that to estimate the variance the loop can be shown to
+		# require many fewer iterations to meet the desired
+		# accuracy, but that choice creates a rather strong bias
+		# that, to overcome, requires some extra hacks to force the
+		# loop to run for additional iterations.  the approach used
+		# here is much simpler.
+				math_sqrt = math.sqrt
+				random_uniform = random.uniform
+				two_epsilon = 2. * self.abundance_rel_accuracy
+				n, d = 0, 0
+				while math_sqrt(d) >= two_epsilon * n:
+					dt = tuple(random_uniform(*window) for window in windows)
+					if all(abs(dt[i] - dt[j]) <= maxdt for i, j, maxdt in ijseq):
+						n += 1
+					d += 1
+				self._coincidence_rate_factors[key] *= float(n) / float(d)
+
+		# done
+		return self._coincidence_rate_factors
+
+
 	@property
 	def rates(self):
 		"""
@@ -958,113 +1060,18 @@ class CoincSynthesizer(object):
 		example, the rate for frozenset(("H1", "L1")) is the rate,
 		in Hz, at which that combination of instruments
 		participates in coincidences, not the rate of H1,L1
-		doubles.  This is a reference to a cached internal
-		dictionary.  Modifications will be retained until the
-		cached data is regenerated (after .reset() is invoked or
-		the .tau or .mu attributes are assigned to).
+		doubles.  The return value is not cached.
 		"""
-		try:
-			return self._rates
-		except AttributeError:
-			all_instruments = set(self.mu)
-			self._rates = {}
-			for instruments in self.all_instrument_combos:
-		# choose the instrument whose TOA forms the "epoch" of the
-		# coinc.  to improve the convergence rate this should be
-		# the instrument with the smallest Cartesian product of
-		# coincidence windows with other instruments (so that
-		# coincidence with this instrument provides the tightest
-		# prior constraint on the time differences between the
-		# other instruments).
-				key = instruments
-				anchor = min(instruments, key = lambda a: sum(math.log(self.tau[frozenset((a, b))]) for b in instruments - set([a])))
-				instruments = tuple(instruments - set([anchor]))
-		# compute \mu_{1} * \mu_{2} ... \mu_{N} * 2 * \tau_{12} * 2
-		# * \tau_{13} ... 2 * \tau_{1N}.  this is the rate at which
-		# events from instrument 1 are coincident with events from
-		# all of instruments 2...N.  later, we will multiply this
-		# by the probability that events from instruments 2...N
-		# known to be coincident with an event from instrument 1
-		# are themselves mutually coincident
-				rate = self.mu[anchor]
-		# the factor of 2 is because to be coincident the time
-		# difference can be anywhere in [-tau, +tau], so the size
-		# of the coincidence window is 2 tau
-				for instrument in instruments:
-					rate *= self.mu[instrument] * 2 * self.tau[frozenset((anchor, instrument))]
-				if self.verbose:
-					print >>sys.stderr, "%s uncorrected mean event rate = %g Hz" % (",".join(sorted(key)), rate)
+		# compute \mu_{1} * \mu_{2} ... \mu_{N} * FACTOR where
+		# FACTOR is the previously-computed proportionality
+		# constant from coincidence_rate_factors.
 
-		# if there are more than two instruments, correct for the
-		# probability of full N-way coincidence by computing the
-		# volume of the allowed parameter space by stone throwing.
-		# FIXME:  it might be practical to solve this with some
-		# sort of computational geometry library and convex hull
-		# volume calculator.
-		# FIXME:  in any case, these correction factors depend only
-		# on the coincidence windows and can be computed and saved
-		# when self.tau is updated allowing the rates, here, to be
-		# computed very quickly if only the single-instrument
-		# trigger rates have changed and not the coincidence
-		# windows.
-				if len(instruments) > 1:
-		# for each instrument 2...N, the interval within which an
-		# event is coincident with instrument 1
-					windows = tuple((-self.tau[frozenset((anchor, instrument))], +self.tau[frozenset((anchor, instrument))]) for instrument in instruments)
-		# pre-assemble a sequence of instrument index pairs and the
-		# maximum allowed \Delta t between them to avoid doing the
-		# work associated with assembling the sequence inside a
-		# loop
-					ijseq = tuple((i, j, self.tau[frozenset((instruments[i], instruments[j]))]) for (i, j) in iterutils.choices(range(len(instruments)), 2))
-		# compute the numerator and denominator of the fraction of
-		# events coincident with the anchor instrument that are
-		# also mutually coincident.  this is done by picking a
-		# vector of allowed \Delta ts and testing them against the
-		# coincidence windows.  the loop's exit criterion is
-		# arrived at as follows.  after d trials, the number of
-		# successful outcomes is a binomially-distributed RV with
-		# variance = d p (1 - p) <= d/4 where p is the probability
-		# of a successful outcome.  we quit when the ratio of the
-		# bound on the standard deviation of the number of
-		# successful outcomes (d/4) to the actual number of
-		# successful outcomes (n) falls below rel accuracy:
-		# \sqrt{d/4} / n < rel accuracy.  note that if the true
-		# probability is 0, so that n=0 identically, then the loop
-		# will never terminate; from the nature of the problem we
-		# know 0<p<1 so the loop will, eventually, terminate.  note
-		# that if instead of using the upper bound on the variance,
-		# we replace p with the estimate of p at the current
-		# iteration (=n/d) and use that to estimate the variance
-		# the loop can be shown to require many fewer iterations to
-		# meet the desired accuracy, but that choice creates a
-		# rather strong bias that, to overcome, requires some extra
-		# hacks to force the loop to run for additional iterations.
-		# the approach used here is much simpler.
-					math_sqrt = math.sqrt
-					random_uniform = random.uniform
-					epsilon = self.abundance_rel_accuracy
-					n, d = 0, 0
-					while math_sqrt(d) >= epsilon * n:
-						dt = tuple(random_uniform(*window) for window in windows)
-						if all(abs(dt[i] - dt[j]) <= maxdt for i, j, maxdt in ijseq):
-		# instead of adding 1 here and multiplying n by 2 in the
-		# loop exit test, we increment n by 2 and then fix it
-		# afterwards.
-							n += 2
-						d += 1
-		# fix n (see above)
-					n //= 2
+		rates = dict(self.coincidence_rate_factors)
+		for instruments in rates:
+			for instrument in instruments:
+				rates[instruments] *= self.mu[instrument]
 
-					rate *= float(n) / float(d)
-					if self.verbose:
-						print >>sys.stderr, "	multi-instrument correction factor = %g" % (float(n)/float(d))
-						print >>sys.stderr, "	%s mean event rate = %g Hz" % (",".join(sorted(key)), rate)
-
-				self._rates[key] = rate
-				if self.verbose:
-					print >>sys.stderr, "%s mean event rate = %g Hz" % (",".join(sorted(key)), rate)
-
-		# self._rates now contains the mean rate at which each
+		# rates now contains the mean rate at which each
 		# combination of instruments can be found in a coincidence
 		# during the times when at least those instruments are
 		# available to form coincidences.  Note:  the rate, e.g.,
@@ -1073,8 +1080,7 @@ class CoincSynthesizer(object):
 		# other higher-order coincidences in which H1 and L1
 		# participate.
 
-			# done
-			return self._rates
+		return rates
 
 
 	@property
@@ -1088,7 +1094,8 @@ class CoincSynthesizer(object):
 		are possible, not the mean rate over all time.  The result
 		is not cached.
 		"""
-		coinc_rate = dict.fromkeys(self.rates, 0.0)
+		rates = self.rates	# don't re-evalute in loop
+		coinc_rate = dict.fromkeys(rates, 0.0)
 		# iterate over probabilities in order for better numerical
 		# accuracy
 		for on_instruments, P_on_instruments in sorted(self.P_live.items(), key = lambda (ignored, P): P):
@@ -1098,7 +1105,7 @@ class CoincSynthesizer(object):
 
 			# rates for instrument combinations that are
 			# possible given the instruments that are on
-			allowed_rates = dict((participating_instruments, rate) for participating_instruments, rate in self.rates.items() if participating_instruments <= on_instruments)
+			allowed_rates = dict((participating_instruments, rate) for participating_instruments, rate in rates.items() if participating_instruments <= on_instruments)
 
 			# subtract from each rate the rate at which that
 			# combination of instruments is found in (allowed)
@@ -1239,7 +1246,7 @@ class CoincSynthesizer(object):
 			events = tuple(random.choice(self.eventlists[instrument]) for instrument in instruments)
 
 			# test for a genuine zero-lag coincidence among them
-			if not allow_zero_lag and any(abs(ta - tb) < self.tau[frozenset((instrumenta, instrumentb))] for (instrumenta, ta), (instrumentb, tb) in iterutils.choices(zip(instruments, (timefunc(event) for event in events)), 2)):
+			if not allow_zero_lag and any(abs(ta - tb) < self.tau[frozenset((instrumenta, instrumentb))] for (instrumenta, ta), (instrumentb, tb) in itertools.combinations(zip(instruments, (timefunc(event) for event in events)), 2)):
 				continue
 
 			# return acceptable event tuples
@@ -1248,30 +1255,31 @@ class CoincSynthesizer(object):
 
 	def plausible_toas(self, instruments):
 		"""
-		Generator that yields dictionaries of random event
-		time-of-arrivals for the instruments in instruments such
-		that the time-of-arrivals are mutually coincident given the
-		maximum allowed inter-instrument \Delta t's.
+		Generator that yields dictionaries of random noise event
+		time-of-arrival offsets for the given instruments such that
+		the time-of-arrivals are mutually coincident given the
+		maximum allowed inter-instrument \Delta t's.  The values
+		returned are offsets, and would need to be added to some
+		common time to yield absolute arrival times.
 
 		Example:
 
-		>>> tau = {frozenset(['V1', 'H1']): 0.028287979933844225, frozenset(['H1', 'L1']): 0.011012846152223924, frozenset(['V1', 'L1']): 0.027448341016726496}
-		>>> instruments = set(("H1", "L1", "V1"))
-		>>> coinc_synth = CoincSynthesizer()
-		>>> coinc_synth.tau = tau	# override
-		>>> toas = coinc_synth.plausible_toas(instruments)
+		>>> # minimal initialization for this method
+		>>> coinc_synth = CoincSynthesizer(segmentlists = {"H1": None, "L1": None, "V1": None}, delta_t = 0.005)
+		>>> toas = coinc_synth.plausible_toas(("H1", "L1", "V1"))
 		>>> toas.next()
 		>>> toas.next()
 		"""
 		# this algorithm is documented in slideless_coinc_generator_rates()
 		instruments = tuple(instruments)
 		anchor, instruments = instruments[0], instruments[1:]
+		anchor_offset = [(anchor, 0.0)]	 # don't build inside loop
 		windows = tuple((-self.tau[frozenset((anchor, instrument))], +self.tau[frozenset((anchor, instrument))]) for instrument in instruments)
-		ijseq = tuple((i, j, self.tau[frozenset((instruments[i], instruments[j]))]) for (i, j) in iterutils.choices(range(len(instruments)), 2))
+		ijseq = tuple((i, j, self.tau[frozenset((instruments[i], instruments[j]))]) for (i, j) in itertools.combinations(range(len(instruments)), 2))
 		while True:
 			dt = tuple(random.uniform(*window) for window in windows)
 			if all(abs(dt[i] - dt[j]) <= maxdt for i, j, maxdt in ijseq):
-				yield dict([(anchor, 0.0)] + zip(instruments, dt))
+				yield dict(anchor_offset + zip(instruments, dt))
 
 
 #
@@ -1516,7 +1524,7 @@ def InstrumentBins(names = ("E0", "E1", "E2", "E3", "G1", "H1", "H2", "H1H2+", "
 	>>> x.centres()[55]
 	frozenset(['H1', 'L1'])
 	"""
-	return rate.HashableBins(frozenset(combo) for n in range(len(names) + 1) for combo in iterutils.choices(names, n))
+	return rate.HashableBins(frozenset(combo) for n in range(len(names) + 1) for combo in itertools.combinations(names, n))
 
 
 #
@@ -1915,16 +1923,16 @@ class CoincParamsDistributions(object):
 # starting from Bayes' theorem:
 #
 # P(coinc is a g.w. | its parameters)
-#     P(those parameters | a coinc known to be a g.w.) * P(coinc is g.w.)
-#   = -------------------------------------------------------------------
-#                                P(parameters)
+#     P(those parameters | coinc is g.w.) * P(coinc is g.w.)
+#   = ------------------------------------------------------
+#                         P(parameters)
 #
-#     P(those parameters | a coinc known to be a g.w.) * P(coinc is g.w.)
-#   = -------------------------------------------------------------------
+#               P(those parameters | coinc is g.w.) * P(coinc is g.w.)
+#   = -------------------------------------------------------------------------
 #     P(noise params) * P(coinc is not g.w.) + P(inj params) * P(coinc is g.w.)
 #
-#                       P(inj params) * P(coinc is g.w.)
-#   = -------------------------------------------------------------------
+#                        P(inj params) * P(coinc is g.w.)
+#   = ---------------------------------------------------------------------------
 #     P(noise params) * [1 - P(coinc is g.w.)] + P(inj params) * P(coinc is g.w.)
 #
 #                        P(inj params) * P(coinc is g.w.)
